==> apache-camel-quarkus-3.16.0-src.zip: camel-quarkus-3.16.0/integration-tests/langchain4j/src/main/java/org/apache/camel/quarkus/component/langchain/it/LangChain4jResource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.langchain.it;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;
import org.apache.camel.ProducerTemplate;

@Path("/langchain4j")
@ApplicationScoped
public class LangChain4jResource {

    @Inject
    ProducerTemplate producerTemplate;

    @Path("/camel-annotations-should-work-as-expected")
    @POST
    @Produces(MediaType.APPLICATION_JSON)
    public String camelAnnotationsShouldWorkAsExpected(String json) {
        return producerTemplate.requestBody("direct:camel-annotations-should-work-as-expected", json, String.class);
    }

}

==> apache-camel-quarkus-3.17.0-src.zip: camel-quarkus-3.17.0/integration-tests/langchain4j/src/main/java/org/apache/camel/quarkus/component/langchain/it/LangChain4jResource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.langchain.it;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;
import org.apache.camel.ProducerTemplate;

@Path("/langchain4j")
@ApplicationScoped
public class LangChain4jResource {

    @Inject
    ProducerTemplate producerTemplate;

    @Path("/camel-annotations-should-work-as-expected")
    @POST
    @Produces(MediaType.APPLICATION_JSON)
    public String camelAnnotationsShouldWorkAsExpected(String json) {
        return producerTemplate.requestBody("direct:camel-annotations-should-work-as-expected", json, String.class);
    }

    @Path("/ai-service-should-be-resolvable-by-interface")
    @GET
    @Produces(MediaType.TEXT_PLAIN)
    public String aiServiceShouldBeResolvableByInterface() {
        return producerTemplate.requestBody("direct:ai-service-should-be-resolvable-by-interface", "dummy-body", String.class);
    }

}
